@@ -15,7 +15,7 @@
 # Author: Alec Thomas <alec@swapoff.org>
 
 revision = "$Rev: 7889 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-0.11.6/sample-plugins/permissions/authz_policy.py $"
+url = "$URL: http://svn.edgewall.org/repos/trac/tags/trac-0.11.7/sample-plugins/permissions/authz_policy.py $"
 
 """Permission policy enforcement through an authz-like configuration file.
 
