@@ -8,7 +8,7 @@ from trac.config import Option, ListOption
 from trac.util.compat import set
 
 revision = "$Rev: 6326 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-0.11.6/sample-plugins/workflow/CodeReview.py $"
+url = "$URL: http://svn.edgewall.org/repos/trac/tags/trac-0.11.7/sample-plugins/workflow/CodeReview.py $"
 
 class CodeReviewActionController(Component):
     """Support for simple code reviews.
