@@ -52,7 +52,7 @@ class Query(object):
 
     def __init__(self, env, report=None, constraints=None, cols=None,
                  order=None, desc=0, group=None, groupdesc=0, verbose=0,
-                 rows=None, page=None, max=None):
+                 rows=None, page=None, max=None, format=None):
         self.env = env
         self.id = report # if not None, it's the corresponding saved query
         self.constraints = constraints or {}
@@ -60,6 +60,7 @@ class Query(object):
         self.desc = desc
         self.group = group
         self.groupdesc = groupdesc
+        self.format = format
         self.default_page = 1
         self.items_per_page = QueryModule(self.env).items_per_page
 
@@ -120,9 +121,10 @@ class Query(object):
 
     def from_string(cls, env, string, **kw):
         filters = string.split('&')
-        kw_strs = ['order', 'group', 'page', 'max']
+        kw_strs = ['order', 'group', 'page', 'max', 'format']
         kw_arys = ['rows']
         kw_bools = ['desc', 'groupdesc', 'verbose']
+        kw_synonyms = {'row': 'rows'}
         constraints = {}
         cols = []
         for filter_ in filters:
@@ -142,6 +144,7 @@ class Query(object):
                 field = field[:-1]
             if not field:
                 raise QuerySyntaxError(_('Query filter requires field name'))
+            field = kw_synonyms.get(field, field)
             processed_values = []
             for val in values.split('|'):
                 val = mode + val # add mode of comparison
@@ -329,6 +332,8 @@ class Query(object):
         if not isinstance(href, Href):
             href = href.href # compatibility with the `req` of the 0.10 API
 
+        if format is None:
+            format = self.format
         if format == 'rss':
             max = self.items_per_page
             page = self.default_page
@@ -716,6 +721,7 @@ class QueryModule(Component):
         by default (''since 0.11'')""")
 
     # IContentConverter methods
+
     def get_supported_conversions(self):
         yield ('rss', _('RSS Feed'), 'xml',
                'trac.ticket.Query', 'application/rss+xml', 8)
@@ -823,8 +829,9 @@ class QueryModule(Component):
                      conversion[1], conversion[4], conversion[0])
 
         if format:
+            filename = ('query', None)[format == 'rss']
             Mimeview(self.env).send_converted(req, 'trac.ticket.Query', query,
-                                              format, filename=None)
+                                              format, filename=filename)
 
         return self.display_html(req, query)
 
@@ -1057,7 +1064,8 @@ class TicketQueryMacro(WikiMacroBase):
 
     For compatibility with Trac 0.10, if there's a second positional parameter
     given to the macro, it will be used to specify the `format`.
-    Also, using "&" as a field separator still works but is deprecated.
+    Also, using "&" as a field separator still works (except for `order`)
+    but is deprecated.
     """
 
     def expand_macro(self, formatter, name, content):
